@@ -18,7 +18,7 @@ static const char* url_escape_table[256] = {
 	"%00", "%01", "%02", "%03", "%04", "%05", "%06", "%07", "%08", "%09",
 	"%0a", "%0b", "%0c", "%0d", "%0e", "%0f", "%10", "%11", "%12", "%13",
 	"%14", "%15", "%16", "%17", "%18", "%19", "%1a", "%1b", "%1c", "%1d",
-	"%1e", "%1f", "+", 0, "%22", "%23", 0, "%25", "%26", "%27", 0, 0, 0,
+	"%1e", "%1f", "%20", 0, "%22", "%23", 0, "%25", "%26", "%27", 0, 0, 0,
 	"%2b", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, "%3c", "%3d",
 	"%3e", "%3f", 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
 	0, 0, 0, 0, 0, 0, 0, 0, 0, "%5c", 0, "%5e", 0, "%60", 0, 0, 0, 0, 0,
@@ -138,7 +138,7 @@ void html_attr(const char *txt)
 	const char *t = txt;
 	while(t && *t){
 		int c = *t;
-		if (c=='<' || c=='>' || c=='\'' || c=='\"') {
+		if (c=='<' || c=='>' || c=='\'' || c=='\"' || c=='&') {
 			html_raw(txt, t - txt);
 			if (c=='>')
 				html("&gt;");
@@ -148,6 +148,8 @@ void html_attr(const char *txt)
 				html("&#x27;");
 			else if (c=='"')
 				html("&quot;");
+			else if (c=='&')
+				html("&amp;");
 			txt = t+1;
 		}
 		t++;
@@ -160,11 +162,11 @@ void html_url_path(const char *txt)
 {
 	const char *t = txt;
 	while(t && *t){
-		int c = *t;
+		unsigned char c = *t;
 		const char *e = url_escape_table[c];
-		if (e && c!='+' && c!='&' && c!='+') {
+		if (e && c!='+' && c!='&') {
 			html_raw(txt, t - txt);
-			html_raw(e, 3);
+			html(e);
 			txt = t+1;
 		}
 		t++;
@@ -177,11 +179,13 @@ void html_url_arg(const char *txt)
 {
 	const char *t = txt;
 	while(t && *t){
-		int c = *t;
+		unsigned char c = *t;
 		const char *e = url_escape_table[c];
+		if (c == ' ')
+			e = "+";
 		if (e) {
 			html_raw(txt, t - txt);
-			html_raw(e, strlen(e));
+			html(e);
 			txt = t+1;
 		}
 		t++;
@@ -288,12 +292,12 @@ char *convert_query_hexchar(char *txt)
 
 int http_parse_querystring(const char *txt_, void (*fn)(const char *name, const char *value))
 {
-	char *t, *txt, *value = NULL, c;
+	char *o, *t, *txt, *value = NULL, c;
 
 	if (!txt_)
 		return 0;
 
-	t = txt = strdup(txt_);
+	o = t = txt = strdup(txt_);
 	if (t == NULL) {
 		printf("Out of memory\n");
 		exit(1);
@@ -316,5 +320,6 @@ int http_parse_querystring(const char *txt_, void (*fn)(const char *name, const
 	}
 	if (t!=txt)
 		(*fn)(txt, value);
+	free(o);
 	return 0;
 }
