@@ -76,6 +76,8 @@ void show_commit_decorations(struct commit *commit)
 			cgit_tag_link(buf, NULL, "tag-deco", ctx.qry.head, buf);
 		}
 		else if (!prefixcmp(deco->name, "refs/remotes/")) {
+			if (!ctx.repo->enable_remote_branches)
+				goto next;
 			strncpy(buf, deco->name + 13, sizeof(buf) - 1);
 			cgit_log_link(buf, NULL, "remote-deco", NULL,
 				      sha1_to_hex(commit->object.sha1),
@@ -88,6 +90,7 @@ void show_commit_decorations(struct commit *commit)
 					 sha1_to_hex(commit->object.sha1),
 					 ctx.qry.vpath, 0);
 		}
+next:
 		deco = deco->next;
 	}
 }
@@ -95,7 +98,6 @@ void show_commit_decorations(struct commit *commit)
 void print_commit(struct commit *commit, struct rev_info *revs)
 {
 	struct commitinfo *info;
-	char *tmp;
 	int cols = revs->graph ? 3 : 2;
 	struct strbuf graphbuf = STRBUF_INIT;
 	struct strbuf msgbuf = STRBUF_INIT;
@@ -130,11 +132,7 @@ void print_commit(struct commit *commit, struct rev_info *revs)
 	}
 	else {
 		html("<td>");
-		tmp = fmt("id=%s", sha1_to_hex(commit->object.sha1));
-		tmp = cgit_fileurl(ctx.repo->url, "commit", ctx.qry.vpath, tmp);
-		html_link_open(tmp, NULL, NULL);
 		cgit_print_age(commit->date, TM_WEEK * 2, FMT_SHORTDATE);
-		html_link_close();
 		html("</td>");
 	}
 
@@ -172,11 +170,7 @@ void print_commit(struct commit *commit, struct rev_info *revs)
 
 	if (revs->graph) {
 		html("</td><td>");
-		tmp = fmt("id=%s", sha1_to_hex(commit->object.sha1));
-		tmp = cgit_fileurl(ctx.repo->url, "commit", ctx.qry.vpath, tmp);
-		html_link_open(tmp, NULL, NULL);
 		cgit_print_age(commit->date, TM_WEEK * 2, FMT_SHORTDATE);
-		html_link_close();
 	}
 
 	if (ctx.repo->enable_log_filecount) {
