@@ -20,7 +20,7 @@ time_t read_agefile(char *path)
 	if (readfile(path, &buf, &size))
 		return -1;
 
-	if (parse_date(buf, buf2, sizeof(buf2)))
+	if (parse_date(buf, buf2, sizeof(buf2)) > 0)
 		result = strtoul(buf2, NULL, 10);
 	else
 		result = 0;
@@ -109,13 +109,13 @@ void print_header(int columns)
 }
 
 
-void print_pager(int items, int pagelen, char *search)
+void print_pager(int items, int pagelen, char *search, char *sort)
 {
 	int i;
 	html("<div class='pager'>");
 	for(i = 0; i * pagelen < items; i++)
 		cgit_index_link(fmt("[%d]", i+1), fmt("Page %d", i+1), NULL,
-				search, i * pagelen);
+				search, sort, i * pagelen);
 	html("</div>");
 }
 
@@ -282,7 +282,7 @@ void cgit_print_repolist()
 	if (!hits)
 		cgit_print_error("No repositories found");
 	else if (hits > ctx.cfg.max_repo_count)
-		print_pager(hits, ctx.cfg.max_repo_count, ctx.qry.search);
+		print_pager(hits, ctx.cfg.max_repo_count, ctx.qry.search, ctx.qry.sort);
 	cgit_print_docend();
 }
 
