@@ -11,7 +11,7 @@ extern char *cgit_pageurl(const char *reponame, const char *pagename,
 			  const char *query);
 
 extern void cgit_index_link(const char *name, const char *title,
-			    const char *class, const char *pattern, int ofs);
+			    const char *class, const char *pattern, const char *sort, int ofs);
 extern void cgit_summary_link(const char *name, const char *title,
 			      const char *class, const char *head);
 extern void cgit_tag_link(const char *name, const char *title,
